@@ -4,8 +4,10 @@ CREATE TABLE events
     aggregate_type text                         NOT NULL,
     aggregate_id   text                         NOT NULL,
     sequence       bigint CHECK (sequence >= 0) NOT NULL,
-    payload        text                        NOT NULL,
-    metadata       text                        NOT NULL,
+    event_type     text                         NOT NULL,
+    event_version  text                         NOT NULL,
+    payload        json                         NOT NULL,
+    metadata       json                         NOT NULL,
     timestamp      timestamp with time zone DEFAULT (CURRENT_TIMESTAMP),
     PRIMARY KEY (aggregate_type, aggregate_id, sequence)
 );
@@ -13,11 +15,12 @@ CREATE TABLE events
 -- this table is only needed if snapshotting is employed
 CREATE TABLE snapshots
 (
-    aggregate_type text                              NOT NULL,
-    aggregate_id   text                              NOT NULL,
-    last_sequence  bigint CHECK (last_sequence >= 0) NOT NULL,
-    payload        text                             NOT NULL,
-    timestamp      timestamp with time zone DEFAULT (CURRENT_TIMESTAMP),
+    aggregate_type   text                                 NOT NULL,
+    aggregate_id     text                                 NOT NULL,
+    last_sequence    bigint CHECK (last_sequence >= 0)    NOT NULL,
+    current_snapshot bigint CHECK (current_snapshot >= 0) NOT NULL,
+    payload          json                                 NOT NULL,
+    timestamp        timestamp with time zone DEFAULT (CURRENT_TIMESTAMP),
     PRIMARY KEY (aggregate_type, aggregate_id, last_sequence)
 );
 
@@ -27,7 +30,7 @@ CREATE TABLE test_query
 (
     query_instance_id text                        NOT NULL,
     version           bigint CHECK (version >= 0) NOT NULL,
-    payload           text                       NOT NULL,
+    payload           json                        NOT NULL,
     PRIMARY KEY (query_instance_id)
 );
 
